==> estateplat-common-1.2.4-20201203.062325-572-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjCbzdDcb.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: sc
 * Date: 15-5-8
 * Time: 下午7:16
 * To change this template use File | Settings | File Templates.
 * dos:土地承包经营权
 */
public class DjsjCbzdDcb {
    private String cbzdDcbIndex;
    private String tdyt;
    private String dldj;
    private String sfjbnt;
    private String syttlx;
    private Double ccgd;
    private Double cdfgd;
    private String dcjs;
    private String dcy;
    private Date dcrq;
    private String shyj;
    private String shr;
    private Date shrq;
    private String bdcdyh;
    private String djh;
    private String zddcbIndex;
    private String yzyfs;
    private String cdysz;
    private Integer syzxl;
    private String cdjq;//草地建群
    private String fbfbm;//发包方编码


    public String getFbfbm() {
        return fbfbm;
    }

    public void setFbfbm(String fbfbm) {
        this.fbfbm = fbfbm;
    }

    public String getCbzdDcbIndex() {
        return cbzdDcbIndex;
    }

    public void setCbzdDcbIndex(String cbzdDcbIndex) {
        this.cbzdDcbIndex = cbzdDcbIndex;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getDldj() {
        return dldj;
    }

    public void setDldj(String dldj) {
        this.dldj = dldj;
    }

    public String getSfjbnt() {
        return sfjbnt;
    }

    public void setSfjbnt(String sfjbnt) {
        this.sfjbnt = sfjbnt;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public Double getCcgd() {
        return ccgd;
    }

    public void setCcgd(Double ccgd) {
        this.ccgd = ccgd;
    }

    public Double getCdfgd() {
        return cdfgd;
    }

    public void setCdfgd(Double cdfgd) {
        this.cdfgd = cdfgd;
    }

    public String getDcjs() {
        return dcjs;
    }

    public void setDcjs(String dcjs) {
        this.dcjs = dcjs;
    }

    public String getDcy() {
        return dcy;
    }

    public void setDcy(String dcy) {
        this.dcy = dcy;
    }

    public Date getDcrq() {
        return dcrq;
    }

    public void setDcrq(Date dcrq) {
        this.dcrq = dcrq;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getShr() {
        return shr;
    }

    public void setShr(String shr) {
        this.shr = shr;
    }

    public Date getShrq() {
        return shrq;
    }

    public void setShrq(Date shrq) {
        this.shrq = shrq;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getZddcbIndex() {
        return zddcbIndex;
    }

    public void setZddcbIndex(String zddcbIndex) {
        this.zddcbIndex = zddcbIndex;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCdysz() {
        return cdysz;
    }

    public void setCdysz(String cdysz) {
        this.cdysz = cdysz;
    }

    public Integer getSyzxl() {
        return syzxl;
    }

    public void setSyzxl(Integer syzxl) {
        this.syzxl = syzxl;
    }
    public String getCdjq() {
        return cdjq;
    }

    public void setCdjq(String cdjq) {
        this.cdjq = cdjq;
    }

}

==> estateplat-common-1.2.4-20220809.092117-1079-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjCbzdDcb.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: sc
 * Date: 15-5-8
 * Time: 下午7:16
 * To change this template use File | Settings | File Templates.
 * dos:土地承包经营权
 */
public class DjsjCbzdDcb {
    private String cbzdDcbIndex;
    private String tdyt;
    private String dldj;
    private String sfjbnt;
    private String syttlx;
    private Double ccgd;
    private Double cdfgd;
    private String dcjs;
    private String dcy;
    private Date dcrq;
    private String shyj;
    private String shr;
    private Date shrq;
    private String bdcdyh;
    private String djh;
    private String zddcbIndex;
    private String yzyfs;
    private String cdysz;
    private Integer syzxl;
    private String cdjq;//草地建群
    private String fbfbm;//发包方编码

    /**
     * 承包起始日期
     */
    private Date cbqsrq;


    /**
     * 承包终止日期
     */
    private Date cbzzrq;


    public String getFbfbm() {
        return fbfbm;
    }

    public void setFbfbm(String fbfbm) {
        this.fbfbm = fbfbm;
    }

    public String getCbzdDcbIndex() {
        return cbzdDcbIndex;
    }

    public void setCbzdDcbIndex(String cbzdDcbIndex) {
        this.cbzdDcbIndex = cbzdDcbIndex;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getDldj() {
        return dldj;
    }

    public void setDldj(String dldj) {
        this.dldj = dldj;
    }

    public String getSfjbnt() {
        return sfjbnt;
    }

    public void setSfjbnt(String sfjbnt) {
        this.sfjbnt = sfjbnt;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public Double getCcgd() {
        return ccgd;
    }

    public void setCcgd(Double ccgd) {
        this.ccgd = ccgd;
    }

    public Double getCdfgd() {
        return cdfgd;
    }

    public void setCdfgd(Double cdfgd) {
        this.cdfgd = cdfgd;
    }

    public String getDcjs() {
        return dcjs;
    }

    public void setDcjs(String dcjs) {
        this.dcjs = dcjs;
    }

    public String getDcy() {
        return dcy;
    }

    public void setDcy(String dcy) {
        this.dcy = dcy;
    }

    public Date getDcrq() {
        return dcrq;
    }

    public void setDcrq(Date dcrq) {
        this.dcrq = dcrq;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getShr() {
        return shr;
    }

    public void setShr(String shr) {
        this.shr = shr;
    }

    public Date getShrq() {
        return shrq;
    }

    public void setShrq(Date shrq) {
        this.shrq = shrq;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getZddcbIndex() {
        return zddcbIndex;
    }

    public void setZddcbIndex(String zddcbIndex) {
        this.zddcbIndex = zddcbIndex;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCdysz() {
        return cdysz;
    }

    public void setCdysz(String cdysz) {
        this.cdysz = cdysz;
    }

    public Integer getSyzxl() {
        return syzxl;
    }

    public void setSyzxl(Integer syzxl) {
        this.syzxl = syzxl;
    }

    public String getCdjq() {
        return cdjq;
    }

    public void setCdjq(String cdjq) {
        this.cdjq = cdjq;
    }

    public Date getCbqsrq() {
        return cbqsrq;
    }

    public void setCbqsrq(Date cbqsrq) {
        this.cbqsrq = cbqsrq;
    }

    public Date getCbzzrq() {
        return cbzzrq;
    }

    public void setCbzzrq(Date cbzzrq) {
        this.cbzzrq = cbzzrq;
    }
}
